==> graphviz_2.22.2-2.tar.gz: graphviz-2.22.2/lib/neatogen/overlap.h <==
/* $Id: overlap.h,v 1.1 2008/12/09 00:03:36 erg Exp $ $Revision: 1.1 $ */
/* vim:set shiftwidth=4 ts=8: */

/**********************************************************
*      This software is part of the graphviz package      *
*                http://www.graphviz.org/                 *
*                                                         *
*            Copyright (c) 1994-2004 AT&T Corp.           *
*                and is licensed under the                *
*            Common Public License, Version 1.0           *
*                      by AT&T Corp.                      *
*                                                         *
*        Information and Software Systems Research        *
*              AT&T Research, Florham Park NJ             *
**********************************************************/

#ifndef OVERLAP_H
#define OVERLAP_H

#ifdef SMOOTHER
#include "post_process.h"

typedef  StressMajorizationSmoother OverlapSmoother;

#define OverlapSmoother_struct StressMajorizationSmoother_struct

void OverlapSmoother_delete(OverlapSmoother sm);

OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m, int dim, real lambda0, real *x, real *width, int include_original_graph, int neighborhood_only,
				    real *max_overlap, real *min_overlap);

void OverlapSmoother_smooth(OverlapSmoother sm, int dim, real *x);

#else
#include "SparseMatrix.h"
#endif

void remove_overlap(int dim, SparseMatrix A, int m, real *x, real *label_sizes, int ntry, real initial_scaling, int *flag);
#endif

==> graphviz_2.26.3.orig.tar.gz: graphviz-2.26.3/lib/neatogen/overlap.h <==
/* $Id: overlap.h,v 1.4 2009/09/04 14:35:04 yifanhu Exp $ $Revision: 1.4 $ */
/* vim:set shiftwidth=4 ts=8: */

/**********************************************************
*      This software is part of the graphviz package      *
*                http://www.graphviz.org/                 *
*                                                         *
*            Copyright (c) 1994-2004 AT&T Corp.           *
*                and is licensed under the                *
*            Common Public License, Version 1.0           *
*                      by AT&T Corp.                      *
*                                                         *
*        Information and Software Systems Research        *
*              AT&T Research, Florham Park NJ             *
**********************************************************/

#ifndef OVERLAP_H
#define OVERLAP_H

#ifdef SMOOTHER
#include "post_process.h"

typedef  StressMajorizationSmoother OverlapSmoother;

#define OverlapSmoother_struct StressMajorizationSmoother_struct

void OverlapSmoother_delete(OverlapSmoother sm);

OverlapSmoother OverlapSmoother_new(SparseMatrix A, int m, int dim, real lambda0, real *x, real *width, int include_original_graph, int neighborhood_only,
				    real *max_overlap, real *min_overlap, int shrink);

void OverlapSmoother_smooth(OverlapSmoother sm, int dim, real *x);

#else
#include "SparseMatrix.h"
#endif

void remove_overlap(int dim, SparseMatrix A, int m, real *x, real *label_sizes, int ntry, real initial_scaling, int *flag);
#endif
